#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import os

from pyspark.ml.clustering import KMeans
from pyspark.sql import SparkSession


def to_csv_line(data):
    return ','.join(str(d) for d in data)


if __name__ == "__main__":
    spark = SparkSession \
        .builder \
        .appName("KMeansExample") \
        .getOrCreate()

    # Loads data via cosn.
    dataset = spark.read.format("libsvm").load(os.environ["P_INPUT0"] + "/sample_kmeans_data.txt")

    # Trains a k-means model.
    kmeans = KMeans().setK(2).setSeed(1)
    model = kmeans.fit(dataset)

    # Make predictions
    predictions = model.transform(dataset)

    # Write the label and prediction back via cosn.
    predictions.drop("features").write.option("header", "true").csv(os.environ["P_OUTPUT0"])

    spark.stop()
